import { __awaiter } from "tslib";
import { Item, Loader } from '@roots/bud-build';
import { Config } from './babel.config';
import { DEFAULT_PLUGINS, DEFAULT_PRESETS, } from './babel.constants';
/**
 * Adds Babel transpiler support to Framework projects
 *
 * @public
 */
export const name = '@roots/bud-babel';
/**
 * Exposes app.babel configuration utility
 *
 * @public
 */
export const mixin = (app) => __awaiter(void 0, void 0, void 0, function* () {
    return ({
        babel: [Config, app],
    });
});
/**
 * Extension register event
 *
 * @public
 */
export const register = (app) => __awaiter(void 0, void 0, void 0, function* () {
    app.build.loaders.babel = new Loader(() => require.resolve('babel-loader'));
    app.build.items.babel = new Item({
        loader: ({ build }) => build.loaders.babel,
        options: app => {
            var _a, _b;
            const options = {
                cacheDirectory: app.path('storage', 'cache', 'babel'),
                env: {
                    development: {
                        compact: false,
                    },
                },
                root: app.path('src'),
            };
            if ((_a = app.babel) === null || _a === void 0 ? void 0 : _a.presets) {
                options.presets = Object.values(app.babel.presets);
            }
            if ((_b = app.babel) === null || _b === void 0 ? void 0 : _b.plugins) {
                options.plugins = Object.values(app.babel.plugins);
            }
            return options;
        },
    });
    app.build.rules.js.use = app => [app.build.items.babel];
    app.babel
        .setPresets(DEFAULT_PRESETS)
        .setPlugins(DEFAULT_PLUGINS);
});
//# sourceMappingURL=babel.extension.js.map